Enum sdc::error::Error
[−]
[src]
pub enum Error {
Byteorder(Error),
InvalidHeaderInformation,
InvalidMajorVersion(u16),
InvalidTargetType(u8),
Io(Error),
Utf8(Utf8Error),
}Our custom error type.
Variants
Byteorder | Wrapper around a |
InvalidHeaderInformation | The header information is invalid. |
InvalidMajorVersion | The sdc file has an invalid major version number. |
InvalidTargetType | The given number cannot be converted to a target type. |
Io | Wrapper around |
Utf8 | Wrapper around |